PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/HugePageAllocator.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions | Variables
HugePageAllocator.hpp File Reference
`#include <cstddef>`
`#include <cstdlib>`
`#include <memory>`
`#include <cstring>`
`#include <new>`
`#include <stdexcept>`
`#include <sys/mman.h>`
`#include <unistd.h>`
`#include <vector>`

Go to the source code of this file.

## Data Structures
struct | AlignedTHPAllocator< T >

## Functions
template<typename T, typename U>
bool | operator== (const AlignedTHPAllocator< T > &, const AlignedTHPAllocator< U > &)
template<typename T, typename U>
bool | operator!= (const AlignedTHPAllocator< T > &, const AlignedTHPAllocator< U > &)

## Variables
constexpr std::size_t | hugepage_size = 2 * 1024 * 1024

## Function Documentation

## ◆ operator!=()

template<typename T, typename U>

bool operator!= | ( | const AlignedTHPAllocator< T > & | ,
|  | const AlignedTHPAllocator< U > & | )

## ◆ operator==()

template<typename T, typename U>

bool operator== | ( | const AlignedTHPAllocator< T > & | ,
|  | const AlignedTHPAllocator< U > & | )

## Variable Documentation

## ◆ hugepage_size

std::size_t hugepage_size = 2 * 1024 * 1024
| constexpr